@@ -34,6 +34,7 @@
 #include <gtk/gtkmenuitem.h>
 #include <gtk/gtkwindow.h>
 #include <libgnome/gnome-i18n.h>
+#include <libgnome/gnome-init.h>
 #include <libgnomeui/gnome-entry.h>
 #include <glade/glade.h>
 #include <bonobo/bonobo-control.h>
@@ -228,8 +229,8 @@ set_word (SpellControlData *cd, gchar *word)
 	gchar *str;
 	gint i;
 
-	str = g_strdup_printf (_("Suggestions for '%s'"), word);
-	gtk_label_set_text (GTK_LABEL (cd->label_word), str);
+	str = g_strdup_printf (_("_Suggestions for '%s'"), word);
+	gtk_label_set_text_with_mnemonic (GTK_LABEL (cd->label_word), str);
 	g_free (str);
 
 	g_free (cd->word);
@@ -407,8 +408,9 @@ gnome_spell_control_new ()
 	BonoboControl *control;
 	GtkWidget *table;
 	GladeXML *xml;
+	gchar *gladefile;
 
-	xml = glade_xml_new (GLADE_DATADIR "/spell-checker.glade", "simple_control", NULL);
+	xml = glade_xml_new (gnome_spell_control_get_glade_file (), "simple_control", NULL);
 	if (!xml)
 		g_error (_("Could not load glade file."));
 	table = glade_xml_get_widget (xml, "simple_control");
@@ -423,3 +425,70 @@ gnome_spell_control_new ()
 		return NULL;
 	}
 }
+
+#ifdef G_OS_WIN32
+
+#include <windows.h>
+
+static HMODULE hmodule;
+
+BOOL WINAPI
+DllMain (HINSTANCE hinstDLL,
+	 DWORD     fdwReason,
+	 LPVOID    lpvReserved)
+{
+        switch (fdwReason) {
+        case DLL_PROCESS_ATTACH:
+                hmodule = hinstDLL;
+                break;
+        }
+        return TRUE;
+}
+
+static char *
+replace_prefix (const char *runtime_prefix,
+                const char *configure_time_path)
+{
+        if (runtime_prefix &&
+            strncmp (configure_time_path, PREFIX "/",
+                     strlen (PREFIX) + 1) == 0)
+                return g_strconcat (runtime_prefix,
+                                    configure_time_path + strlen (PREFIX),
+                                    NULL);
+        else
+                return g_strdup (configure_time_path);
+}
+
+#endif
+
+
+const gchar *
+gnome_spell_control_get_glade_file ()
+{
+#ifndef G_OS_WIN32
+	return GLADE_DATADIR "/spell-checker.glade";
+#else
+	static char *gladefile = NULL;
+
+	if (!gladefile) {
+		gchar *utf8_prefix, *cp_prefix, *tem;
+
+		gnome_win32_get_prefixes (hmodule, &utf8_prefix, &cp_prefix);
+
+		/* As the libgnome-spell-component DLL is in
+		 * <runtime-prefix>/lib/gnome-spell, the utf8_prefix
+		 * returned is that directory. Strip two directory
+		 * levels leaving just <runtime-prefix>.
+		 */
+		tem = g_path_get_dirname (utf8_prefix);
+		g_free (utf8_prefix);
+		utf8_prefix = g_path_get_dirname (tem);
+		g_free (tem);
+		gladefile = replace_prefix (utf8_prefix, GLADE_DATADIR "/spell-checker.glade");
+		g_free (utf8_prefix);
+		g_free (cp_prefix);
+	}
+
+	return gladefile;
+#endif
+}
